@@ -9,5 +9,6 @@ NULL
 
 utils::globalVariables(c(
   "ymin", "ymax", "lower", "upper", "sig", "d",
-  "contrast", "RE", "log2FC", "Lower.se", "Upper.se", "Lower.se.RE", "Upper.se.RE"
-))
\ No newline at end of file
+  "contrast", "RE", "log2FC", "Lower.se", "Upper.se", 
+  "Lower.se.RE", "Upper.se.RE", "factors", "as.formula", "tail", "Gene"
+))
